@@ -1,5 +1,4 @@
 ### R code from vignette source 'shortintro.Rnw'
-### Encoding: ASCII
 
 ###################################################
 ### code chunk number 1: check
@@ -12,9 +11,8 @@ RNGkind()
 ###################################################
 RNGkind()
 library(randtoolbox)
-paramParkMiller <- c(mod=2^31-1, mult=16807, incr=0)
-set.generator(name="congruRand", parameters=paramParkMiller, seed=1)
-get.description()
+set.generator("MersenneTwister", initialization="init2002", resolution=53, seed=1)
+str(get.description())
 RNGkind()
 runif(10)
 
